## Version 0.4.0 - 2022-01-20

* Add an optional on_yaml_loaded event on the app.

## Version 0.3.0 - 2022-01-20

* Update dependencies

## Version 0.2.3 - 2021-04-28

 * Fix packaging
 * Add tests and examples

## Version 0.1.3 - 2021-04-27

 * Initial release
